#!/bin/bash

#   FILE: speak.sh -- Festival will read the file which is the first command 
#         line argument.
# AUTHOR: W. Michael Petullo <speak@flyn.org>
#   DATE: 19 SEP 1998

ESD=`which esd`
SPEAK_COMMAND=/usr/share/festival/examples/text2wave

if test "$#" = 0; then
	echo "Usage: $0 filename."
	exit
fi

if [ -f /tmp/be_nice ]; then
	# Don't want to take up CPU cycles.
	# echo "CPU intensive process in progress, exiting."
	exit
fi

if [ -f /tmp/speaking/$1 ]; then
	# Another process is already trying to speak this file, give up.
	exit
fi

if [ ! -d /tmp/speaking ]; then
	mkdir /tmp/speaking
else
	# Another process is speaking, wait until it is done.
	while [ -d /tmp/speaking ]; do
	        sleep 60
	done
fi

dir=`dirname $1`
mkdir -p /tmp/speaking/$dir
touch /tmp/speaking/$1

if [ -r $1 ]; then
	if /sbin/fuser $ESD | grep -c '[0123456789]' > /dev/null; then
		$SPEAK_COMMAND -F 44100 -otype raw < $1 | esdcat -r 44100 -m
	else
		$SPEAK_COMMAND -otype raw -F 44100 < $1 \
			| sox -t raw -r 44100 -w -s -c 1 - \
			      -t ossdsp -r 44100 -w -s -c 2 /dev/dsp
	fi
fi

rm -rf /tmp/speaking
